@@ -1,8 +1,10 @@
 #
-# notes2.tcl - v2.1.0 - released by MHT <mht@mygale.org>
+# notes2.tcl - v2.1.1 - released by MHT <mht@mygale.org>
 #                     - a bind apart script from #TSF
 #                     - for eggdrop 1.3.15+
 #
+# $Id: notes2.tcl,v 1.6 2001-11-05 04:08:28 guppy Exp $
+#
 ####
 #
 # history:
@@ -25,6 +27,9 @@
 #         Generally never happens, except in case of 'Chriphil's syndrome' ;-p
 #       - Added missing 'You don't have that many messages.'
 #
+# 2.1.1 - fixed a couple of small bugs pertaining to $nick being used instead of
+#         $botnet-nick (found by takeda, fixed by guppy)
+#
 ####
 # Check your notes on every shared bot of the hub.
 #
@@ -47,7 +52,7 @@ bind   bot  - notes2reply: *bot:notes2reply
 
 ########
 proc n2_notesindex {bot handle idx} {
-    global nick
+    global nick botnet-nick
     switch "([notes $handle])" {
 	"(-2)" { putbot $bot "notes2reply: $handle Notefile failure. $idx" }
 	#"-1" { putbot $bot "notes2reply: $handle I don't know you. $idx" }
@@ -64,7 +69,7 @@ proc n2_notesindex {bot handle idx} {
 		    putbot $bot "notes2reply: $handle %$index. $sender ($date) $idx"
 		}
 	    }
-	    putbot $bot "notes2reply: $handle ### Use '.notes $nick read' to read them. $idx"
+	    putbot $bot "notes2reply: $handle ### Use '.notes ${botnet-nick} read' to read them. $idx"
 	}
     }
     return 1
@@ -147,7 +152,7 @@ proc *bot:notes2 {handle idx arg} {
 
 ########
 proc *bot:notes2reply {handle idx arg} {
-    # verify that idx is valid (older scripts does not provide idx)
+    # verify that idx is valid (older scripts do not provide idx)
     set idx [lindex $arg end]
     if {([valididx $idx]) && ([idx2hand $idx] == [lindex $arg 0])} {
 	set reply [lrange $arg 1 [expr [llength $arg]-2]]
@@ -170,14 +175,14 @@ proc *chon:notes2 {handle idx} {
 
 ########
 proc *dcc:notes2 {handle idx arg} {
-    global nick
+    global nick botnet-nick
     if {$arg == ""} {
 	putidx $idx "Usage: notes \[bot|all\] index"
 	putidx $idx "       notes \[bot|all\] read <#|all>"
 	putidx $idx "       notes \[bot|all\] erase <#|all>"
 	putidx $idx "       # may be numbers and/or intervals separated by ;"
 	putidx $idx "       ex: notes erase 2-4;8;16-"
-	putidx $idx "           notes $nick read all"
+	putidx $idx "           notes ${botnet-nick} read all"
     } else {
 	set bot [string tolower [lindex $arg 0]]
 	set cmd [string tolower [lindex $arg 1]]
@@ -192,7 +197,7 @@ proc *dcc:notes2 {handle idx arg} {
 		    return [*dcc:notes $handle $idx $arg]
 		}
 	    } else {
-		putidx $idx "I don't know anybot by that name."
+		putidx $idx "I don't know any bot by that name."
 		return 0
 	    }
 	} elseif {($cmd != "index") && ($cmd != "read") && ($cmd != "erase")} {
