@@ -2,11 +2,11 @@
  * channels.c -- part of channels.mod
  *   support for channels within the bot
  *
- * $Id: channels.c,v 1.93 2006-03-28 02:35:50 wcc Exp $
+ * $Id: channels.c,v 1.96 2008-02-16 21:41:06 guppy Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2006 Eggheads Development Team
+ * Copyright (C) 1999 - 2008 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -123,6 +123,9 @@ static void set_mode_protect(struct chanset_t *chan, char *set)
     case 'N':
       i = CHANNONOTC;
       break;
+    case 'T':
+      i = CHANNOAMSG;
+      break;
     case 't':
       i = CHANTOPIC;
       break;
@@ -221,6 +224,8 @@ static void get_mode_protect(struct chanset_t *chan, char *s)
       *p++ = 'u';
     if (tst & CHANNONOTC)
       *p++ = 'N';
+    if (tst & CHANNOAMSG)
+      *p++ = 'T';
     if (tst & CHANTOPIC)
       *p++ = 't';
     if (tst & CHANNOMSG)
