@@ -1,11 +1,11 @@
 /*
  * tclchan.c -- part of channels.mod
  *
- * $Id: tclchan.c,v 1.94 2006-03-28 02:35:50 wcc Exp $
+ * $Id: tclchan.c,v 1.97 2008-02-16 21:41:07 guppy Exp $
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2006 Eggheads Development Team
+ * Copyright (C) 1999 - 2008 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1489,17 +1489,25 @@ static int tcl_channel_modify(Tcl_Interp *irp, struct chanset_t *chan,
 static int tcl_do_masklist(maskrec *m, Tcl_Interp *irp)
 {
   char ts[21], ts1[21], ts2[21], *p;
+  long tv;
   EGG_CONST char *list[6];
 
   for (; m; m = m->next) {
     list[0] = m->mask;
     list[1] = m->desc;
-    sprintf(ts, "%lu", m->expire);
+
+    tv = m->expire;
+    sprintf(ts, "%lu", tv);
     list[2] = ts;
-    sprintf(ts1, "%lu", m->added);
+
+    tv = m->added;
+    sprintf(ts1, "%lu", tv);
     list[3] = ts1;
-    sprintf(ts2, "%lu", m->lastactive);
+
+    tv = m->lastactive;
+    sprintf(ts2, "%lu", tv);
     list[4] = ts2;
+
     list[5] = m->user;
     p = Tcl_Merge(6, list);
     Tcl_AppendElement(irp, p);
